@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=4.7.2
+gcc_version=4.7.3
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -33,23 +33,16 @@ done
 
 archive=${1-gcc-$gcc_version.tar.bz2}
 
-rm -f $top/s-sources
-rm -f $top/s-patch
+if test "$tar_param" = "xf" ; then
+    echo "Failed to detect how to decompress $archive"
+    exit 1
+fi
 
 rm -rf gnu
 mkdir gnu
-case $archive in 
-      *.tgz | *.tar.gz )
-         ( cd gnu && tar xzf $top/$archive && echo $archive >$top/s-sources )
-         ;;
-      *.tar.bz2 )
-         ( cd gnu && tar xf $top/$archive --use=bzip2 && echo $archive >$top/s-sources )
-         ;;
-      *)
-         echo "Unknown archive format ($top/$archive)"
-	 exit 1	
-         ;; 
-esac
+
+rm -f $top/s-sources
+( cd gnu && tar xf $top/$archive --use=`case $archive in *.gz|*.tgz) echo 'gzip';; *.bz2) echo 'bzip2';; *.xz) echo 'xz';; esac` && echo $archive >$top/s-sources )
 
 if ! [ -f s-sources ] ; then
     echo "Cannot unpack GCC sources"
@@ -126,18 +119,15 @@ aclocal_list=
 #
 #  File copy instructions required for building cross-compiler
 #
-file_copy_list_1=
+file_copy_list_1=""
 
 #
 #  Additional file copy instructions required for building native-compiler
 #
 
-if $create_gccnnns_zip ; then
-    file_copy_list_2="gcc/ada/system.ads:system-djgpp.ads";
-else
-    file_copy_list_2=;
-fi
+file_copy_list_2="";
 
+#
 patching_ok=true
 
 for copy_instr in $file_copy_list_1 $file_copy_list_2 ; do
@@ -188,12 +178,12 @@ for x in $patch_instr_list_1 $patch_instr_list_2; do
     x=$(echo $x | sed -e 's:diffs2*/source/::')
 
     case $x in 
-       *.diff | *.diff[0-9] | *.diff[0-9][0-9])
+       *.diff | *.diff.in)
            cd $top
            diff=`pwd`/$x;
-           fname=`echo $x | sed -e 's/\.diff[0-9]*//g'`
+           fname=`echo $x | sed -e 's/\.diff//g'`
 
-           echo "Applying patch $x to gcc/$fname ..."
+           echo "Applying patch to gcc/$fname ..."
            if [ -f $gcc_dir/$fname ] ; then
               cp -f $gcc_dir/$fname $gcc_dir/${fname}~1 
               if ! patch --verbose --suffix=$backup_name $gcc_dir/$fname <$patch_src ; then
